Workflow functions
==================

.. contents::
   :depth: 3
   :backlinks: entry
   :local:

Install Module
______________

Snakecdysis offer the facility to easy install workflow configuration on Local or HPC.

.. click:: snakecdysis.__main__:main
    :prog: PKGNAME
    :commands: install_local
    :nested: complete
    :hide-header:

.. click:: snakecdysis.__main__:main
    :prog: PKGNAME
    :commands: install_cluster
    :nested: complete
    :hide-header:
